@@ -40,44 +40,6 @@ CAPABILITY_AUTO_EXPAND = 'CAPABILITY_AUTO_EXPAND'
 
 po = PrettyObject()
 
-_deletion_stack = []
-
-def add_to_deletion_stack(stack_name: str):
-    global _deletion_stack
-    dstring = f"cfm.delete_stack(stack_name = '{stack_name}')\n"
-    _deletion_stack.append(dstring)
-
-def write_deletion_stack(fname: str):
-    """
-    Writes a python file that, when run, deletes the resources created since the last time this was executed (or the last call of clear_deletion_stack()).
-    You'll want to run this whenever you create a set of dependent stacks that should be removed as a single unit.
-
-    :param fname: The path to the deletion script you're creating. The file should be named something like 'xyz.py' - the output is a python script.
-    """
-    global _deletion_stack
-    out = "from aws import cfm\nprint('deleting stacks:')\n"
-    while len(_deletion_stack) > 0:
-      out += _deletion_stack.pop()
-    file = None
-    try:
-      file = open(fname, 'wt')
-      file.seek(0)
-      file.write(out)
-      file.truncate()
-      print(f"wrote stack deletion file '{fname}'")
-      clear_deletion_stack()
-    finally:
-      if file is not None:
-        file.close()
-
-def clear_deletion_stack():
-    """
-    Clears the deletion stack. Use when you don't want to include previously created resources in the next deletion script you generate with write_deletion_stack().
-    Note: This happens automatically whenever you call write_deletion_stack(), so there's no need to call it immediately following a write.
-    """
-    global _deletion_stack
-    _deletion_stack = []
-
 def list_stacks(stack_status_filter=None):
     """
     Gets a list of all stacks.
@@ -86,7 +48,7 @@ def list_stacks(stack_status_filter=None):
     :return: a list of all stack summaries or None if the filter was bad
     """
     client = region.get_cloudformation()
-    if stack_status_filter is str:
+    if type(stack_status_filter) is str:
         stack_status_filter = [stack_status_filter]  # handles single filter as string
     stacks_remain = True
     all_stacks = []
@@ -106,7 +68,7 @@ def list_stacks(stack_status_filter=None):
                 token = stacks['NextToken']
             stacks_remain = 'NextToken' in stacks
     except ClientError:
-        return None
+        return []
     return all_stacks
 
 
@@ -136,7 +98,7 @@ def describe_stacks(stack_name=None):
                 token = stacks['NextToken']
             stacks_remain = 'NextToken' in stacks
     except ClientError:  # if the stack_name provided isn't found
-        return None
+        return []
     return all_stacks
 
 
@@ -260,17 +222,17 @@ def create_stack(fn: str, params={}, capabilities=[], stack_name: str = None, ta
     :return: `cloudformation.Stack <https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudformation.html#stack>`_
     """
     client = region.get_cloudformation()
-    file = None
+
     try:
         # create stack name
         (path, filename) = os.path.split(fn)
         if stack_name is None:
-            stack_name = params['EnvType'] + '-' + filename.split('.')[0]
+            stack_name = params['VpcName'] + '-' + filename.split('.')[0]
 
         # if stack already exists, skip and return true
         if stack_exists(stack_name):
             print(f"{stack_name} already exists - skipping stack creation.")
-            return True
+            return get_stack(stack_name)
 
         print(f"Creating {stack_name}...")
 
@@ -314,17 +276,11 @@ def create_stack(fn: str, params={}, capabilities=[], stack_name: str = None, ta
             delete_stack(stack_name)
             raise Exception(f'Stack creation failed: {stack_name}')
 
-        add_to_deletion_stack(stack_name)
-
         return summary
 
     except IOError as e:
         print(f"Can't open stack {e}") 
 
-    finally: 
-        if file is not None:
-            file.close()
-
 
 def get_export_value(stack_name: str, export_name: str):
     """
@@ -357,3 +313,63 @@ def delete_stack(stack_name: str):
     status = wait_for_stack(stack_name, DELETE_IN_PROGRESS)
 
     return status
+
+
+def get_output(stack, output_key: str):
+    """
+    Get output value from a given stack and output key. Either a stack dict or just the stack name can be provided.
+
+    :param stack: Either a stack name or a stack dict.
+    :param output_key: The output key to find
+    """
+    if type(stack) is str:
+        stack_dict = get_stack(stack)
+    elif type(stack) is dict:
+        stack_dict = stack
+    else:
+        raise TypeError('Stack must be of type str or dict')
+
+    if 'Outputs' not in stack_dict:
+        raise ValueError('Invalid stack object: "Ouputs" property not found.')
+
+    return next((o['OutputValue'] for o in stack_dict['Outputs'] if o.get('OutputKey') == output_key), None)
+
+
+def get_resources(stack_name: str):
+    """
+    Get a list of stack resources
+
+    :param stack_name: Name of stack
+    :return: A list of resource details (`StackResource <https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudformation.html#stackresource>`_)
+    """
+    if not stack_exists(stack_name):
+        raise ValueError(f'Stack not found: {stack_name}')
+
+    return region.get_cloudformation().describe_stack_resources(
+        StackName=stack_name
+    )['StackResources']
+
+
+def get_resource(stack_name: str, logical_id: str):
+    """
+    Get a stack resource with the given logical id.
+
+    :param stack_name: Name of stack
+    :param logical_id: The logical id of the resource (its key in the CloudFormation template).
+    :return: The resource details (`StackResource <https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudformation.html#stackresource>`_)
+    """
+    resources = get_resources(stack_name)
+    match = ( resource for resource in resources if resource['LogicalResourceId'] == logical_id )
+    return next(match, None)
+
+
+def get_resource_id(stack_name: str, logical_id: str):
+    """
+    Get the physical id  of a stack resource with the given logical id.
+
+    :param stack_name: Name of stack
+    :param logical_id: The logical id of the resource (its key in the CloudFormation template).
+    :return: The physical resource id (ARN, Name, etc.)
+    """
+    resource = get_resource(stack_name, logical_id)
+    return resource['PhysicalResourceId'] if resource else None
