@@ -165,15 +165,14 @@ def set_current_vpcid(vpc: dict = None, vpcid: str = None):
     global _default_vpcid
     global _vpc_filter
 
-    if vpc is not None:
+    if vpc:
         vpcid = get_vpcid(vpc)
+
+    if vpcid:
         _vpc_filter = [
             {'Name': 'vpc-id', 'Values': [vpcid]}
         ]
-
-
     else:
-        vpcid = vpcid
         _vpc_filter = None
 
     _default_vpcid = vpcid
