@@ -89,8 +89,8 @@ def get_db_cluster(id: str):
 
     """
 
-    cluster = get_rds().describe_db_clusters(Filters=[{'Name': 'db-cluster-id','Values': [id]}]).get('DBClusters')
-    return cluster
+    clusters = get_rds().describe_db_clusters(Filters=[{'Name': 'db-cluster-id','Values': [id]}]).get('DBClusters')
+    return clusters[0] if clusters else None
 
 def set_db_cluster_delete_protection(id: str, protect: bool):
     """
@@ -250,8 +250,8 @@ def get_db_instance(id: str):
 
     """
 
-    instance = get_rds().describe_db_instances(Filters=[{'Name': 'db-instance-id','Values': [id]}]).get('DBInstances')
-    return instance
+    instances = get_rds().describe_db_instances(Filters=[{'Name': 'db-instance-id','Values': [id]}]).get('DBInstances')
+    return instances[0] if instances else None
 
 def set_db_instance_delete_protection(id: str, protect: bool):
     """
@@ -416,9 +416,10 @@ def get_subnet_group(id: str):
     :return: `Database Subnet Groups Details <https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds.html#RDS.Client.describe_db_subnet_groups>`_
 
     """
-
-    db_subnet_group = get_rds().describe_db_subnet_groups(DBSubnetGroupName=id).get('DBSubnetGroups')
-    return db_subnet_group
+    for group in list_subnet_groups():
+        if group['DBSubnetGroupName'] == id:
+            return group
+    return None
 
 
 ###########################################################################
@@ -456,8 +457,10 @@ def get_db_sg(id: str):
     :return: `Database Security Groups Details <https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds.html#RDS.Client.describe_db_security_groups>`_
 
     """
-    db_security_group = get_rds().describe_db_security_groups(DBSecurityGroupName=id).get('DBSecurityGroups')
-    return db_security_group
+    for group in list_db_sgs():
+        if group['DBSecurityGroupName'] == id:
+            return group
+    return None
 
 ###########################################################################
 # Tags
@@ -483,28 +486,4 @@ def get_rds_tags(arn: str):
         key = x.get('Key')
         val = x.get('Value')
         res[key] = val
-    return res
-
-def delete_cluster(id: str):
-    """
-    Delete the database cluster associated with the provided ID
-
-    :param id: The ID of the database cluster
-    :return: `Deleted database cluster details <https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds.html#RDS.Client.delete_db_cluster>`_
-
-    """
-
-    res = get_rds().delete_db_cluster(DBClusterIdentifier=id)
-    return res
-
-def delete_instance(id: str):
-    """
-    Delete the database instance associated with the provided ID
-
-    :param id: The ID of the database instance
-    :return: `Deleted database instance details <https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds.html#RDS.Client.delete_db_instance>`_
-
-    """
-
-    res = get_rds().delete_db_instance(DBInstanceIdentifier=id)
     return res
\ No newline at end of file
